@@ -7,20 +7,18 @@ package Boxer::CLI::Command::About;
 use v5.14;
 use utf8;
 use strictures 2;
-use version;
 use Role::Commons -all;
+use namespace::autoclean 0.16;
 
 use Boxer::CLI -command;
 
-use namespace::clean;
-
 =head1 VERSION
 
-Version v1.1.7
+Version v1.4.0
 
 =cut
 
-our $VERSION = version->declare("v1.1.7");
+our $VERSION = "v1.4.0";
 
 use constant {
 	abstract   => q[list which boxer plugins are installed],
@@ -51,7 +49,7 @@ sub execute
 		FORMAT_STR,
 		ref( $self->app ),
 		$self->app->VERSION,
-		$auth ? $self->app->$auth : '???',
+		$auth ? $self->app->$auth || '???' : '???',
 	);
 
 	foreach my $cmd ( sort $self->app->command_plugins ) {
@@ -60,7 +58,7 @@ sub execute
 			FORMAT_STR,
 			$cmd,
 			$cmd->VERSION,
-			$auth ? $cmd->$auth : '???',
+			$auth ? $cmd->$auth || '???' : '???',
 		);
 	}
 }
