@@ -11,22 +11,22 @@ Boxer::World - set of software available to install
 use v5.14;
 use utf8;
 use strictures 2;
-use version;
 use Role::Commons -all;
 use namespace::autoclean 0.16;
 use autodie;
 
 use Moo;
 use MooX::StrictConstructor;
-use Types::Standard qw(ArrayRef InstanceOf);
+use Types::Standard qw( ArrayRef InstanceOf );
+with qw(MooX::Role::Logger);
 
 =head1 VERSION
 
-Version v1.3.0
+Version v1.4.0
 
 =cut
 
-our $VERSION = version->declare("v1.3.0");
+our $VERSION = "v1.4.0";
 
 =head1 DESCRIPTION
 
